#!/bin/sh

# set -x
# exec > /dev/pts/0 2>&1

self="$(readlink -f "$0")"
if [ ! "$1" = "--rexec" ]; then
	echo "/bin/sh $self --rexec" > /var/exec.flag
	exit
fi

[ -f "/var/squashfs/etc/init.d/moon-game" ] && buttonA="2201" || buttonA="2501"
cpu_freq_path="/sys/devices/system/cpu/cpu0/cpufreq"
cpu_boot_freq="$cpu_freq_path/cpuinfo_boot_freq"
cpu_max_freq="$cpu_freq_path/cpuinfo_max_freq"
cpu_max_scale="$cpu_freq_path/scaling_max_freq"

ocTemp(){
	while true; do
		curTemp="$(cat /sys/class/thermal/thermal_zone0/temp)"
		printf "\e[8;0f\e[K" > /dev/tty0
		echo -e "\t\e[1mCurrent temperature:\e[0m $curTemp°C / $((curTemp*9/5+32))°F" > /dev/tty0
		sleep 2
	done
}

ocCurrent(){
	if [ "$(cat "$cpu_max_scale")" = "$(cat "$cpu_boot_freq")" ]; then
		oc="boot"
	elif [ "$(cat "$cpu_max_scale")" = "$(cat "$cpu_max_freq")" ]; then
		oc="max"
	fi
	curFreq="$(dc "$(cat "$cpu_max_scale")" 1000000 / p)GHz"
}

ocButton(){
	buttons="$(cat /dev/input/event4 | hexdump -v -e '1/1 "%02x"' -n 32)" 
	buttons="${buttons:20:4}"
	case "$buttons" in
		"$buttonA")
			if [ "$oc" = "boot" ]; then
				cat "$cpu_max_freq" > "$cpu_max_scale"
				ocCurrent
				printf "\e[18;0f\e[K" > /dev/tty0
				echo -e "\tNew frequency set to: $curFreq" > /dev/tty0
			else
				printf "\e[18;0f\e[K" > /dev/tty0
				echo -e "\tAlready overclocked!" > /dev/tty0
			fi
			break
			;;
		2101)
			if [ "$oc" = "boot" ]; then
				printf "\e[18;0f\e[K" > /dev/tty0
				echo -e "\tAlready at default frequency!" > /dev/tty0
			else
				cat "$cpu_boot_freq" > "$cpu_max_scale"
				ocCurrent
				printf "\e[18;0f\e[K" > /dev/tty0
				echo -e "\tFrequency restored to: $curFreq" > /dev/tty0
			fi
			break
			;;
		*) kill -9 "$temppid" && kill -9 "$joypid" && return 1 ;;
	esac
	sleep 2
	printf "\e[6;0f\e[K\e[18;0f\e[K" > /dev/tty0
	ocChoice
}

ocChoice(){
	printf "\e[0;0f" > /dev/tty0
	echo -e "\n\n\n\t\e[31m/!\\ USE AT YOUR OWN RISK /!\\ \e[0m\n" > /dev/tty0
	echo -e "\t\e[1mCurrent frequency:\e[0m $curFreq\n" > /dev/tty0
	echo -e "\n\n\t---\n\tPress A button to overclock.\n" > /dev/tty0
	echo -e "\tPress B button to restore default frequency.\n" > /dev/tty0
	echo -e "\tPress any other button to exit.\n\t---" > /dev/tty0
	ocButton
}

uistop
while pgrep ReedPlayer; do
	usleep 50000
done > /dev/null

printf "\e[3J" > /dev/tty0

sntool joydriver md > /dev/null &
joypid="$!"

timeout -t 3 bash -c 'while [ ! -c "/dev/input/event4" ]; do usleep 50000; done'
if [ ! "$?" = "0" ]; then
	kill -9 "$joypid"
	clear > /dev/tty0
	echo -e "\n\n\n\tNo controller detected!\n\n\tExiting..." > /dev/tty0
	sleep 2
	uistart
	exit 1
fi

ocTemp &
temppid="$!"
ocCurrent
ocChoice

wait
uistart
